@@ -132,7 +132,14 @@ def build_android_bundle(app_path):
     print("🔄 Syncing to Android...")
     if not sync_platform(app_path, "android"):
         print("❌ Android sync failed")
-        return None
+        # Try to recover by creating necessary files
+        android_dir_path = Path(app_path) / "android"
+        if android_dir_path.exists():
+            print("🔧 Android directory exists, trying to recover...")
+            _ensure_android_manifest_exists(android_dir_path)
+        else:
+            print("❌ Android directory missing, sync completely failed")
+            return None
     
     android_dir = os.path.join(app_path, "android")
     
@@ -155,6 +162,9 @@ def build_android_bundle(app_path):
     # Get the .aab file path before building
     expected_aab_path = os.path.join(android_dir, "app", "build", "outputs", "bundle", "release", "app-release.aab")
     
+    # CRITICAL: Ensure AndroidManifest.xml exists before any modifications
+    _ensure_android_manifest_exists(Path(android_dir))
+    
     # Ensure applicationId and manifest provider authorities are aligned with Play package
     _ensure_application_id(Path(android_dir))
     _align_manifest_package(Path(android_dir))
@@ -228,6 +238,68 @@ def _read_text_safe(p: Path) -> str:
         except Exception:
             return ""
 
+def _ensure_android_manifest_exists(android_dir: Path) -> None:
+    """Ensure AndroidManifest.xml exists before building."""
+    manifest_path = android_dir / "app" / "src" / "main" / "AndroidManifest.xml"
+    
+    if not manifest_path.exists():
+        print("⚠️ AndroidManifest.xml missing! Creating basic manifest...")
+        
+        # Ensure the directory exists
+        manifest_path.parent.mkdir(parents=True, exist_ok=True)
+        
+        # Create a basic AndroidManifest.xml
+        basic_manifest = '''<?xml version="1.0" encoding="utf-8"?>
+<manifest xmlns:android="http://schemas.android.com/apk/res/android">
+
+    <application
+        android:allowBackup="true"
+        android:icon="@mipmap/ic_launcher"
+        android:label="@string/app_name"
+        android:roundIcon="@mipmap/ic_launcher_round"
+        android:supportsRtl="true"
+        android:theme="@style/AppTheme.NoActionBarLaunch">
+
+        <activity
+            android:configChanges="orientation|keyboardHidden|keyboard|screenSize|locale|smallestScreenSize|screenLayout|uiMode|navigation"
+            android:name=".MainActivity"
+            android:exported="true"
+            android:launchMode="singleTask"
+            android:theme="@style/AppTheme.NoActionBarLaunch">
+
+            <intent-filter android:autoVerify="true">
+                <action android:name="android.intent.action.MAIN" />
+                <category android:name="android.intent.category.LAUNCHER" />
+            </intent-filter>
+
+        </activity>
+
+        <provider
+            android:name="androidx.core.content.FileProvider"
+            android:authorities="${applicationId}.fileprovider"
+            android:exported="false"
+            android:grantUriPermissions="true">
+            <meta-data
+                android:name="android.support.FILE_PROVIDER_PATHS"
+                android:resource="@xml/file_paths"></meta-data>
+        </provider>
+    </application>
+
+    <!-- Permissions -->
+    <uses-permission android:name="android.permission.INTERNET" />
+
+</manifest>'''
+        
+        try:
+            manifest_path.write_text(basic_manifest, encoding='utf-8')
+            print(f"✅ Created AndroidManifest.xml: {manifest_path}")
+        except Exception as e:
+            print(f"❌ Failed to create AndroidManifest.xml: {e}")
+            raise
+    else:
+        print(f"✅ AndroidManifest.xml exists: {manifest_path}")
+
+
 def _ensure_application_id(android_dir: Path) -> None:
     """Force applicationId to match Play Console package name.
     Controlled by env AIROBO_ANDROID_APPLICATION_ID (defaults to com.aiaroboacademy.app).
@@ -289,29 +361,161 @@ def _align_manifest_package(android_dir: Path) -> None:
         manifest.write_text(new_xml, encoding="utf-8")
         print(f"🏷️ Manifest package aligned to: {target_app_id}")
 
+def _override_android12_splash_screen(android_dir, source_splash):
+    """
+    MEGA NUCLEAR OPTION: Override Android 12+ Splash Screen API completely
+    This forcibly disables the new splash screen API and forces our custom splash
+    """
+    print("🔥 OVERRIDING Android 12+ Splash Screen API...")
+    
+    # 1. Create themes.xml specifically for Android 12+
+    res_dir = android_dir / "app" / "src" / "main" / "res"
+    values_v31_dir = res_dir / "values-v31"  # Android 12+ (API 31+)
+    values_v31_dir.mkdir(parents=True, exist_ok=True)
+    
+    themes_v31_file = values_v31_dir / "themes.xml"
+    themes_v31_content = """<?xml version="1.0" encoding="utf-8"?>
+<resources>
+    <!-- Android 12+ (API 31+) Splash Screen Override -->
+    <style name="AppTheme" parent="Theme.Material3.DayNight.NoActionBar">
+        <!-- DISABLE Android 12+ splash screen API -->
+        <item name="android:windowSplashScreenBackground">@drawable/splash</item>
+        <item name="android:windowSplashScreenAnimatedIcon">@drawable/splash</item>
+        <item name="android:windowSplashScreenIconBackgroundColor">@android:color/transparent</item>
+        <item name="android:windowSplashScreenBrandingImage">@drawable/splash</item>
+        <!-- Force immediate transition to avoid app icon -->
+        <item name="android:windowSplashScreenAnimationDuration">0</item>
+        <!-- Traditional splash screen fallback -->
+        <item name="android:windowBackground">@drawable/splash</item>
+        <item name="android:windowFullscreen">true</item>
+        <item name="android:windowContentOverlay">@null</item>
+        <item name="android:windowNoTitle">true</item>
+    </style>
+    
+    <!-- Force main activity to use our splash -->
+    <style name="SplashTheme" parent="AppTheme">
+        <item name="android:windowBackground">@drawable/splash</item>
+        <item name="android:windowSplashScreenBackground">@drawable/splash</item>
+        <item name="android:windowSplashScreenAnimatedIcon">@drawable/splash</item>
+        <item name="android:windowSplashScreenBrandingImage">@drawable/splash</item>
+    </style>
+</resources>"""
+    
+    themes_v31_file.write_text(themes_v31_content, encoding='utf-8')
+    print(f"   ✅ Created Android 12+ themes override: {themes_v31_file}")
+    
+    # 2. Modify AndroidManifest.xml to explicitly disable splash screen API
+    manifest_files = list(android_dir.rglob("AndroidManifest.xml"))
+    for manifest_file in manifest_files:
+        if "main" in str(manifest_file):
+            try:
+                manifest_content = manifest_file.read_text(encoding='utf-8')
+                
+                # Smart AndroidManifest.xml modification - check existing attributes
+                updated_manifest = manifest_content
+                
+                # Add theme attribute if not present
+                if 'android:theme=' not in manifest_content:
+                    updated_manifest = re.sub(
+                        r'(<application[^>]*?)(\s*>)',
+                        r'\1\n        android:theme="@style/SplashTheme"\2',
+                        updated_manifest
+                    )
+                else:
+                    # Replace existing theme with SplashTheme
+                    updated_manifest = re.sub(
+                        r'android:theme="[^"]*"',
+                        'android:theme="@style/SplashTheme"',
+                        updated_manifest
+                    )
+                
+                # Add enableOnBackInvokedCallback if not present 
+                if 'android:enableOnBackInvokedCallback=' not in updated_manifest:
+                    updated_manifest = re.sub(
+                        r'(<application[^>]*?)(\s*>)',
+                        r'\1\n        android:enableOnBackInvokedCallback="false"\2',
+                        updated_manifest
+                    )
+                
+                # Only add allowBackup if not already present
+                if 'android:allowBackup=' not in updated_manifest:
+                    updated_manifest = re.sub(
+                        r'(<application[^>]*?)(\s*>)',
+                        r'\1\n        android:allowBackup="false"\2',
+                        updated_manifest
+                    )
+                
+                # Also ensure MainActivity uses SplashTheme
+                if 'android:name=".MainActivity"' in updated_manifest:
+                    updated_manifest = re.sub(
+                        r'(<activity[^>]*?android:name="\.MainActivity"[^>]*?)(\s*>)',
+                        r'\1\n            android:theme="@style/SplashTheme"\2',
+                        updated_manifest
+                    )
+                
+                if updated_manifest != manifest_content:
+                    manifest_file.write_text(updated_manifest, encoding='utf-8')
+                    print("   🔥 FORCED AndroidManifest.xml Android 12+ splash screen disable")
+                
+            except Exception as e:
+                print(f"   ⚠️ Could not update AndroidManifest.xml for Android 12+: {e}")
+    
+    # 3. Create a Capacitor plugin configuration override
+    try:
+        app_cache_root = android_dir.parent
+        capacitor_config = app_cache_root / "capacitor.config.ts"
+        
+        if capacitor_config.exists():
+            config_content = capacitor_config.read_text(encoding='utf-8')
+            
+            # Add splash screen plugin configuration
+            splash_plugin_config = """
+  plugins: {
+    SplashScreen: {
+      launchShowDuration: 0,
+      launchAutoHide: true,
+      launchFadeOutDuration: 0,
+      backgroundColor: "#000000",
+      androidSplashResourceName: "splash",
+      androidScaleType: "CENTER_CROP",
+      showSpinner: false,
+      androidSpinnerStyle: "large",
+      splashFullScreen: true,
+      splashImmersive: true,
+    },
+  },"""
+            
+            if "SplashScreen:" not in config_content:
+                # Add plugin config before the closing brace
+                updated_config = config_content.replace(
+                    "};",
+                    splash_plugin_config + "\n};"
+                )
+                capacitor_config.write_text(updated_config, encoding='utf-8')
+                print("   ✅ Added Capacitor SplashScreen plugin override")
+        
+    except Exception as e:
+        print(f"   ⚠️ Could not update Capacitor config: {e}")
+    
+    print("🔥 Android 12+ splash screen override COMPLETE!")
+
 def _ensure_app_icon(android_dir: Path) -> None:
     """Copy appIcon.png and splash screen from config locations and generate Android resources."""
     print("🔍 Looking for app icon and splash screen...")
     
-    # Look for appIcon - prioritize SVG vectors for perfect quality!
+    # Look for appIcon.png in known config locations - SIMPLE PNG ONLY
     icon_candidates = [
         os.environ.get("AIROBO_APP_ICON_PATH"),
-        r"C:\airoboConfigs\appIcon.svg",     # 🎯 SVG FIRST for vector quality!
         r"C:\airoboConfigs\appIcon.png",
-        r"C:\airobo\appIcon.svg",
         r"C:\airobo\appIcon.png",
-        os.path.expanduser("~/airoboConfigs/appIcon.svg"),
         os.path.expanduser("~/airoboConfigs/appIcon.png"),
     ]
     
-    # Look for splash screen - prioritize SVG vectors!
+    # Look for splash screen - SIMPLE PNG ONLY
     splash_candidates = [
         os.environ.get("AIROBO_SPLASH_PATH"),
-        r"C:\airoboConfigs\splash.svg",      # 🎯 SVG FIRST for vector quality!
         r"C:\airoboConfigs\splash.png",
-        r"C:\airobo\splash.svg",
-        r"C:\airobo\splash.png",
-        os.path.expanduser("~/airoboConfigs/splash.svg"),
+        r"C:\airobo\splash.png", 
         os.path.expanduser("~/airoboConfigs/splash.png"),
     ]
     
@@ -360,6 +564,7 @@ def _ensure_app_icon(android_dir: Path) -> None:
         "mipmap-xhdpi": 192,     # Was 128, now 2x higher  
         "mipmap-xxhdpi": 288,    # Was 192, now 2x higher
         "mipmap-xxxhdpi": 384,   # Was 256, now 2x higher - ULTRA crisp!
+        "mipmap-anydpi-v26": 384, # For adaptive icon XML
     }
     
     res_dir = android_dir / "app" / "src" / "main" / "res"
@@ -370,55 +575,34 @@ def _ensure_app_icon(android_dir: Path) -> None:
         from PIL import Image
         print("📦 Pillow loaded successfully")
         
-        # Check if we need to handle SVG files
-        is_svg_icon = source_icon and source_icon.suffix.lower() == '.svg'
-        is_svg_splash = source_splash and source_splash.suffix.lower() == '.svg'
-        
-        if is_svg_icon or is_svg_splash:
-            try:
-                import cairosvg
-                print("🎨 CairoSVG loaded for vector processing")
-            except ImportError:
-                print("⚠️ CairoSVG not installed. Installing for SVG processing...")
-                import subprocess
-                subprocess.run([
-                    "pip", "install", "cairosvg"
-                ], check=True, capture_output=True)
-                import cairosvg
-                print("✅ CairoSVG installed successfully")
+        # Simple PNG processing - no SVG complexity
         
         def load_icon_at_size(size):
-            """Load icon at specified size, handling both PNG and SVG"""
-            if is_svg_icon:
-                # Convert SVG to PNG at exact size for perfect quality
-                import io
-                png_data = cairosvg.svg2png(
-                    url=str(source_icon), 
-                    output_width=size, 
-                    output_height=size
-                )
-                return Image.open(io.BytesIO(png_data))
-            else:
-                # Load PNG and resize
-                with Image.open(source_icon) as img:
-                    # Convert to RGBA if needed
-                    if img.mode != 'RGBA':
-                        img = img.convert('RGBA')
-                    return img.resize((size, size), Image.Resampling.LANCZOS)
-        
-        # Load source image for initial processing
-        if is_svg_icon:
-            # For SVG, load at a reasonable preview size
-            with load_icon_at_size(512) as img:
-                print(f"🎨 Vector icon loaded: {img.size[0]}x{img.size[1]} pixels (from SVG)")
-        else:
+            """Load icon at specified size - PNG ONLY with proper transparency"""
             with Image.open(source_icon) as img:
-                print(f"🖼️ Source image: {img.size[0]}x{img.size[1]} pixels, mode: {img.mode}")
-                
-                # Convert to RGBA if needed for transparency support
+                # Force RGBA mode for proper transparency
                 if img.mode != 'RGBA':
                     img = img.convert('RGBA')
-                    print("🔄 Converted to RGBA mode")
+                
+                # Create a new transparent image at target size
+                result = Image.new('RGBA', (size, size), (0, 0, 0, 0))
+                
+                # Resize the source image maintaining aspect ratio
+                img_resized = img.resize((size, size), Image.Resampling.LANCZOS)
+                
+                # Paste onto transparent background (no white ring!)
+                result.paste(img_resized, (0, 0), img_resized)
+                
+                return result
+        
+        # Load source image for initial processing
+        with Image.open(source_icon) as img:
+            print(f"🖼️ Source image: {img.size[0]}x{img.size[1]} pixels, mode: {img.mode}")
+            
+            # Convert to RGBA if needed for transparency support
+            if img.mode != 'RGBA':
+                img = img.convert('RGBA')
+                print("🔄 Converted to RGBA mode")
             
             # FIRST: Replace web icons that Capacitor might use as source
             web_icons_updated = 0
@@ -460,6 +644,26 @@ def _ensure_app_icon(android_dir: Path) -> None:
                 density_dir = res_dir / density
                 density_dir.mkdir(parents=True, exist_ok=True)
                 
+                # Skip PNG generation for anydpi-v26 (only XML files there)
+                if density == "mipmap-anydpi-v26":
+                    # ONLY create adaptive icon XML to prevent white background
+                    adaptive_xml_content = '''<?xml version="1.0" encoding="utf-8"?>
+<adaptive-icon xmlns:android="http://schemas.android.com/apk/res/android">
+    <background android:drawable="@android:color/transparent"/>
+    <foreground android:drawable="@mipmap/ic_launcher_foreground"/>
+</adaptive-icon>'''
+                    adaptive_xml_path = density_dir / "ic_launcher.xml"
+                    adaptive_xml_path.write_text(adaptive_xml_content, encoding='utf-8')
+                    
+                    # Round variant
+                    round_xml_path = density_dir / "ic_launcher_round.xml"
+                    round_xml_path.write_text(adaptive_xml_content, encoding='utf-8')
+                    
+                    print(f"   🎯 Adaptive XML: {adaptive_xml_path}")
+                    print(f"   🎯 Round XML: {round_xml_path}")
+                    icons_created += 2
+                    continue
+                
                 # For adaptive icons, we need larger foreground images (108dp safe area)
                 # The visible area is ~72dp, but we need 108dp for the full adaptive icon
                 adaptive_size = int(size * 1.5)  # 1.5x for 108dp vs 72dp
@@ -490,43 +694,27 @@ def _ensure_app_icon(android_dir: Path) -> None:
             
             # SPLASH SCREENS: Replace all splash screens if splash image is provided
             if source_splash:
-                print(f"🎨 Updating splash screens with proper densities...")
-                print(f"   🎨 Processing {'SVG vector' if is_svg_splash else 'PNG raster'} splash...")
+                print(f"🎨 Updating splash screens - SIMPLE PNG PROCESSING...")
                 splash_files_updated = 0
                 
                 def load_splash_at_size(width, height):
-                    """Load splash at specified size, handling both PNG and SVG"""
-                    if is_svg_splash:
-                        # Convert SVG to PNG at exact size for perfect quality
-                        import io
-                        png_data = cairosvg.svg2png(
-                            url=str(source_splash), 
-                            output_width=width, 
-                            output_height=height
-                        )
-                        return Image.open(io.BytesIO(png_data))
-                    else:
-                        # Load PNG and resize
-                        with Image.open(source_splash) as splash_img:
-                            return splash_img.resize((width, height), Image.Resampling.LANCZOS)
-                
-                # Get source dimensions for logging
-                if is_svg_splash:
-                    print(f"   📏 Vector splash: scalable SVG")
-                else:
+                    """Load splash at specified size - PNG ONLY"""
                     with Image.open(source_splash) as splash_img:
-                        print(f"   📏 Source splash: {splash_img.size[0]}x{splash_img.size[1]}")
+                        return splash_img.resize((width, height), Image.Resampling.LANCZOS)
                 
-                # FIRST: Create main splash drawable in drawable folder (not density-specific)
+                # Get source dimensions
+                with Image.open(source_splash) as splash_img:
+                    print(f"   📏 Source splash: {splash_img.size[0]}x{splash_img.size[1]}")
+                
+                # CRITICAL: Replace the main splash drawable directly
                 main_drawable_dir = res_dir / "drawable"
                 main_drawable_dir.mkdir(parents=True, exist_ok=True)
                 main_splash_path = main_drawable_dir / "splash.png"
                 
-                # Create high-quality main splash
-                main_splash = load_splash_at_size(1080, 1920)  # Standard FHD resolution
-                main_splash.save(main_splash_path, "PNG", optimize=False, compress_level=1)
-                print(f"   🎯 Main splash: 1080x1920 -> {main_splash_path}")
-                main_splash.close()
+                # Copy the source splash directly - no resizing for main drawable
+                with Image.open(source_splash) as splash_img:
+                    splash_img.save(main_splash_path, "PNG", optimize=False, compress_level=1)
+                    print(f"   🎯 Main splash: {splash_img.size[0]}x{splash_img.size[1]} -> {main_splash_path}")
                 splash_files_updated += 1
                 
                 # Standard splash screen sizes for different densities
@@ -577,49 +765,115 @@ def _ensure_app_icon(android_dir: Path) -> None:
                             splash_files_updated += 1
                             default_splash.close()
                 
-                # CRITICAL: Update styles.xml to ensure splash screen uses our image, not app icon
-                styles_file = res_dir / "values" / "styles.xml"
-                if styles_file.exists():
-                    print("🎨 Updating styles.xml to prevent app icon fallback...")
-                    try:
-                        styles_content = styles_file.read_text(encoding='utf-8')
-                        
-                        # Replace the problematic Theme.SplashScreen with a custom theme that doesn't use app icon
-                        updated_styles = styles_content.replace(
-                            'parent="Theme.SplashScreen"', 'parent="Theme.AppCompat.Light.NoActionBar"'
-                        ).replace(
-                            '@mipmap/ic_launcher', '@drawable/splash'
-                        ).replace(
-                            '@mipmap/ic_launcher_foreground', '@drawable/splash'  
-                        ).replace(
-                        )
-                        
-                        # Also ensure we have proper splash screen styling that prevents icon usage
-                        if 'AppTheme.NoActionBarLaunch' in updated_styles:
-                            # Add window splash screen properties to override Android 12+ behavior
-                            splash_theme_section = '''<style name="AppTheme.NoActionBarLaunch" parent="Theme.AppCompat.Light.NoActionBar">
+                # AGGRESSIVE: Also replace any files that might be used as splash fallbacks
+                potential_splash_files = [
+                    "splash_screen.png", "launch_screen.png", "startup.png", 
+                    "background.png", "launch_background.png"
+                ]
+                for filename in potential_splash_files:
+                    for density_folder in ["drawable", "drawable-hdpi", "drawable-xhdpi", "drawable-xxhdpi"]:
+                        potential_path = res_dir / density_folder / filename
+                        if potential_path.parent.exists():
+                            potential_path.parent.mkdir(parents=True, exist_ok=True)
+                            fallback_splash = load_splash_at_size(1080, 1920)
+                            fallback_splash.save(potential_path, "PNG", optimize=False, compress_level=1)
+                            print(f"   🎯 Created fallback: {potential_path}")
+                            fallback_splash.close()
+                            splash_files_updated += 1
+                
+                # NUCLEAR: Create styles.xml to completely override splash behavior
+                styles_dir = res_dir / "values"
+                styles_dir.mkdir(parents=True, exist_ok=True)
+                styles_file = styles_dir / "styles.xml"
+                
+                print("🎨 Creating styles.xml to force custom splash screen...")
+                
+                # Create comprehensive styles.xml that forces splash screen usage
+                splash_styles_content = '''<?xml version="1.0" encoding="utf-8"?>
+<resources>
+    <!-- Base application theme -->
+    <style name="AppTheme" parent="Theme.AppCompat.Light.DarkActionBar">
+        <item name="colorPrimary">@color/colorPrimary</item>
+        <item name="colorPrimaryDark">@color/colorPrimaryDark</item>
+        <item name="colorAccent">@color/colorAccent</item>
+    </style>
+
+    <!-- FORCED Custom splash screen theme - NO APP ICON ALLOWED -->
+    <style name="AppTheme.NoActionBarLaunch" parent="Theme.AppCompat.Light.NoActionBar">
         <item name="android:background">@drawable/splash</item>
+        <item name="android:windowBackground">@drawable/splash</item>
         <item name="android:windowSplashScreenBackground">@drawable/splash</item>
         <item name="android:windowSplashScreenAnimatedIcon">@drawable/splash</item>
         <item name="android:windowSplashScreenIconBackgroundColor">@android:color/transparent</item>
+        <item name="android:windowSplashScreenBrandingImage">@drawable/splash</item>
         <item name="windowActionBar">false</item>
         <item name="windowNoTitle">true</item>
-    </style>'''
-                            
-                            # Replace the existing splash theme
-                            import re
-                            pattern = r'<style name="AppTheme\.NoActionBarLaunch".*?</style>'
-                            updated_styles = re.sub(pattern, splash_theme_section, updated_styles, flags=re.DOTALL)
+        <item name="android:windowContentOverlay">@null</item>
+    </style>
+
+    <!-- Alternative splash theme -->
+    <style name="SplashTheme" parent="Theme.AppCompat.Light.NoActionBar">
+        <item name="android:background">@drawable/splash</item>
+        <item name="android:windowBackground">@drawable/splash</item>
+        <item name="windowActionBar">false</item>
+        <item name="windowNoTitle">true</item>
+    </style>
+</resources>'''
+                
+                try:
+                    styles_file.write_text(splash_styles_content, encoding='utf-8')
+                    print("   ✅ FORCED styles.xml creation with custom splash screen")
+                    print("   🎯 Android MUST use @drawable/splash instead of app icon")
+                    
+                    # Also create colors.xml if it doesn't exist
+                    colors_file = styles_dir / "colors.xml"
+                    if not colors_file.exists():
+                        colors_content = '''<?xml version="1.0" encoding="utf-8"?>
+<resources>
+    <color name="colorPrimary">#3F51B5</color>
+    <color name="colorPrimaryDark">#303F9F</color>
+    <color name="colorAccent">#FF4081</color>
+</resources>'''
+                        colors_file.write_text(colors_content, encoding='utf-8')
+                        print("   📝 Created colors.xml for theme support")
+                        
+                except Exception as e:
+                    print(f"   ⚠️ Could not create styles.xml: {e}")
+                
+                # NUCLEAR OPTION: Also modify AndroidManifest.xml to enforce splash theme
+                manifest_file = android_dir / "app" / "src" / "main" / "AndroidManifest.xml"
+                if manifest_file.exists():
+                    try:
+                        manifest_content = manifest_file.read_text(encoding='utf-8')
+                        
+                        # Ensure the main activity uses our splash theme
+                        updated_manifest = manifest_content.replace(
+                            'android:theme="@style/AppTheme.NoActionBarLaunch"',
+                            'android:theme="@style/SplashTheme"'
+                        )
+                        
+                        # Also replace any other theme references
+                        updated_manifest = updated_manifest.replace(
+                            'android:theme="@style/AppTheme"',
+                            'android:theme="@style/SplashTheme"'
+                        )
+                        
+                        if updated_manifest != manifest_content:
+                            manifest_file.write_text(updated_manifest, encoding='utf-8')
+                            print("   🔥 FORCED AndroidManifest.xml to use SplashTheme")
+                            print("   💥 MainActivity will now ONLY show custom splash screen")
                         
-                        if updated_styles != styles_content:
-                            styles_file.write_text(updated_styles, encoding='utf-8')
-                            print("   ✅ Updated styles.xml to use splash drawable instead of app icon")
-                            print("   🎯 Disabled Android 12+ splash screen API that forces app icon usage")
-                        else:
-                            print("   ℹ️ styles.xml already configured correctly")
-                            
                     except Exception as e:
-                        print(f"   ⚠️ Could not update styles.xml: {e}")
+                        print(f"   ⚠️ Could not update AndroidManifest.xml: {e}")
+                
+                # MEGA NUCLEAR OPTION: Override Android 12+ Splash Screen API completely
+                print("🔥 IMPLEMENTING MEGA NUCLEAR SPLASH SCREEN OVERRIDE...")
+                try:
+                    # TEMPORARILY DISABLED - causing AndroidManifest.xml parse errors
+                    print("   ⚠️ Android 12+ override temporarily disabled to fix build")
+                    # _override_android12_splash_screen(android_dir, source_splash)
+                except Exception as e:
+                    print(f"   ⚠️ Android 12+ override failed: {e}")
                 
                 print(f"🎨 Generated {splash_files_updated} splash screen files across multiple densities")
                 print("🎯 Splash screen should now display your custom image, not the app icon")
